@@ -48,9 +48,9 @@ class BaseWidget:
         if dev:
             infile = os.path.join(current_dir, f"../../webapps/{app_name}/build/static/js/main.js")
             if not os.path.exists(infile):
-                infile = os.path.join(current_dir, f"../../webapps/{app_name}/dist/main.js.gz")
+                infile = os.path.join(current_dir, f"jscodes/{app_name}.js.gz")
         else:
-            infile = os.path.join(current_dir, f"../../webapps/{app_name}/dist/main.js.gz")
+            infile = os.path.join(current_dir, f"jscodes/{app_name}.js.gz")
         self.jscode = deserialize_text(infile)
         self.app_id = str(uuid4())
         self.app_js_render_fn = "".join([s.capitalize() for s in app_name.replace("-", "_").split("_")]) + "." + ('renderDevApp' if self.dev else 'renderApp')
